GrpcInvocationPayload<Q, R> class

Wraps all gRPC invocation data needed by GrpcMessageResolver.handleMessage to set up the Serinus context and invoke the service method.

Constructors

GrpcInvocationPayload({required ServiceCall call, required Stream<Q> requests, required ServiceMethod<Q, R> method, required ServerStreamingInvoker<Q, R> invoker})
Creates a gRPC invocation payload.

Properties

call → ServiceCall
The gRPC service call.
final
hashCode int
The hash code for this object.
no setterinherited
invoker → ServerStreamingInvoker<Q, R>
The invoker that calls the actual service method.
final
method → ServiceMethod<Q, R>
The service method descriptor.
final
requests Stream<Q>
The original requests stream from the gRPC server.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited