resolvedMessageRoutes property
The resolvedMessageRoutes property contains the resolved message routes of the application.
Implementation
final Map<String, GrpcServiceContext> resolvedMessageRoutes = {};
The resolvedMessageRoutes property contains the resolved message routes of the application.
final Map<String, GrpcServiceContext> resolvedMessageRoutes = {};