GrpcMessageResolver class
The GrpcMessageResolver class is the gRPC implementation of the MessagesResolver class.
Constructors
-
GrpcMessageResolver(ApplicationConfig config, void onServicesExtracted(List<
Service> service)) -
The GrpcMessageResolver constructor is used to create a new instance of the
MessagesResolverclass.
Properties
- config → ApplicationConfig
-
The
configproperty contains the application configuration.finalinherited - hashCode → int
-
The hash code for this object.
no setterinherited
-
onServicesExtracted
↔ void Function(List<
Service> service) -
Callback used to create a server correctly with all the services extracted from the module scopes at runtime.
getter/setter pair
- resolvedAlready ↔ bool
-
The resolvedAlready property is used to check if the routes have been resolved already.
getter/setter pair
-
resolvedMessageRoutes
→ Map<
String, GrpcServiceContext> -
The resolvedMessageRoutes property contains the resolved message routes of the application.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handleEvent(
MessagePacket packet, TransportAdapter< dynamic, TransportOptions> adapter) → Future<void> - Handle an incoming event packet. It does not return a response packet.
-
handleMessage(
MessagePacket packet, TransportAdapter< dynamic, TransportOptions> adapter) → Future<ResponsePacket?> - Handle an incoming message packet and return a response packet if applicable.
-
handleRpcCall<
O, R> (MessagePacket packet, TransportAdapter< dynamic, TransportOptions> adapter) → Future<ResponsePacket?> - Handles an incoming gRPC call by setting up the Serinus context and invoking the appropriate service method.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
) → void - Resolve the incoming message packet.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited