GrpcServiceContext<T> class
The GrpcRouteContext class is the gRPC route context.
Constructors
-
GrpcServiceContext({required Map<
Type, Provider> providers, required HooksContainer hooks, required Set<ExceptionFilter> exceptionFilters, required Set<Pipe> pipes, required Map<ValueToken, Object?> values, required List<Metadata> metadata, bool streaming = false}) -
Creates a gRPC route context.
const
Properties
-
exceptionFilters
→ Set<
ExceptionFilter> -
The exceptionFilters property contains the exception filters available in the context.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hooks → HooksContainer
-
The hooks property contains the hooks available in the context.
final
-
metadata
→ List<
Metadata> -
Add metadata to the route context for use in hooks and filters.
final
-
pipes
→ Set<
Pipe> -
The pipes property contains the pipes available in the context.
final
-
providers
→ Map<
Type, Provider> -
The providers property contains the providers available in the context.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streaming → bool
-
Indicates whether the handler is streaming.
final
-
values
→ Map<
ValueToken, Object?> -
The values property contains the value tokens available in the context.
final
Methods
-
initMetadata(
ExecutionContext< RpcArgumentsHost> executionContext) → Future<Map< String, Metadata> > - Initializes the metadata for the route context, resolving any contextualized metadata using the provided execution context.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited