transporters/transporters library
Classes
- GrpcClient
- A gRPC transport client.
- GrpcClientOptions
- gRPC client options.
-
GrpcInvocationPayload<
Q, R> - Wraps all gRPC invocation data needed by GrpcMessageResolver.handleMessage to set up the Serinus context and invoke the service method.
- GrpcMessageResolver
-
The GrpcMessageResolver class is the gRPC implementation of the
MessagesResolverclass. - GrpcOptions
- The GrpcOptions class is the gRPC transport options.
-
GrpcServiceContext<
T> -
The
GrpcRouteContextclass is the gRPC route context. - GrpcServiceController
- The GrpcServiceController allows defining gRPC services as Serinus Controllers.
- GrpcTransport
- A gRPC transport adapter.
- JsonSocket
- A TCP socket implementation that encodes and decodes messages as JSON.
- SerinusInterceptor
- The SerinusInterceptor class is the gRPC interceptor for Serinus.
- TcpClient
- A TCP transport client.
- TcpClientOptions
- TCP client options.
- TcpEvents
- TCP event class.
- TcpOptions
- TCP transport options.
- TcpSocket
- Abstract TCP socket class.
- TcpTransport
- A TCP transport adapter.
Extensions
- ServiceCallContext on ServiceCall
-
The
GrpcUnaryHandlertypedef is the gRPC unary handler function.
Properties
-
grpcContexts
→ Expando<
RpcContext> -
The grpcContexts expando is used to store the gRPC context for each request. This allows us to access the gRPC context from anywhere in the code, as long as we have access to the request object. The gRPC context contains information about the request, such as the metadata and the service call.
final